window.Gleam.initSearch([{"doc":"glychee","title":"glychee","content":"# Glychee\n\n[![Package Version](https://img.shields.io/hexpm/v/glychee)](https://hex.pm/packages/glychee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glychee/)\n\nA simple Gleam benchmark runner which wraps\n[Benchee](https://github.com/bencheeorg/benchee) for the heavy lifting.\n\nNamed after [Gleam](https://gleam.run), Benchee and their fruity offspring, [Lychee](https://en.wikipedia.org/wiki/Lychee):\n\n&lt;img src=&quot;https://upload.wikimedia.org/wikipedia/commons/4/46/Litchi_chinensis_fruits.JPG&quot; alt=&quot;photo of a Lychee&quot; style=&quot;max-height: 10em&quot;/&gt;\n\n## Quick start\n\n_Notice: Requires at least gleam 0.24 (or gleam 0.0.0-nightly-221019 or later)._\n\nAlso requires `Elixir` and `hex` be installed. You might be required to run\n`mix local.hex` after installing Elixir.\n\n1. Add glychee to your project: `gleam add glychee`.\n2. Create a a custom benchmarking module for example named `my_benchmark` that\n   contains a `main`-function. In that module you will define which `Function`s\n   to benchmark with one or many `Data`.\n3. Run the benchmark:\n\n   ```sh\n   gleam clean &amp;&amp; \\\n   gleam build &amp;&amp; \\\n   erl -pa ./build/dev/erlang/*/ebin -noshell -eval &#39;gleam@@main:run(my_benchmark)&#39;\n   ```\n\n### Full example\n\nIf you do not have a Gleam project yet, create it with:\n\n```sh\ngleam new foobar\ncd foobar\n```\n\nIn your project create a file named `src/benchmark.gleam` with following\nsource code:\n\n```gleam\nif erlang {\n  import glychee/benchmark\n  import gleam/list\n  import gleam/int\n\n  pub fn main() {\n    benchmark.run(\n      [\n        benchmark.Function(\n          label: &quot;list.sort()&quot;,\n          fun: fn(test_data) {\n            fn() {\n              list.sort(test_data, int.compare)\n            }\n          },\n        ),\n      ],\n      [\n        benchmark.Data(\n          label: &quot;pre-sorted list&quot;,\n          data: list.range(1, 100_000),\n        ),\n        benchmark.Data(\n          label: &quot;reversed list&quot;,\n          data: list.range(1, 100_000)\n          |&gt; list.reverse,\n        ),\n      ],\n    )\n  }\n}\n```\n\nThen run in your terminal via:\n\n```sh\ngleam clean &amp;&amp; \\\ngleam build &amp;&amp; \\\nerl -pa ./build/dev/erlang/*/ebin -noshell -eval &#39;gleam@@main:run(benchmark)&#39;\n```\n\nNow you can alter the functions and data specified in above&#39;s example to\nwhichever function of your application or library you want to benchmark.\n\nNote that you can benchmark multiple functions with different data sets\nin one go.\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add glychee\n```\n\nGlychee&#39;s documentation can be found at &lt;https://hexdocs.pm/glychee&gt;.\n\n## License\n\nApache 2.0\n","url":"index.html"},{"doc":"glychee/benchmark","title":"Data","content":"pub type Data(data) {\n  Data(label: String, data: data)\n}\n Data pairs arbitrary data, such as a `List(Int)` with a label.\n\n The label is used as part of the benchmark&#39;s stdout output.\n\nData(label: String, data: data)\n\n\nSynonyms:\nglychee/benchmark.Data\nglychee/benchmark Data","url":"glychee/benchmark.html#Data"},{"doc":"glychee/benchmark","title":"Function","content":"pub type Function(test_data, any) {\n  Function(label: String, fun: fn(test_data) -&gt; any)\n}\n Function pairs a `label` with a function returning a callable.\n The function requires some `test_data`.\n\n The label is used as part of the benchmark&#39;s stdout output.\n\nFunction(label: String, fun: fn(test_data) -&gt; any)\n\n\nSynonyms:\nglychee/benchmark.Function\nglychee/benchmark Function","url":"glychee/benchmark.html#Function"},{"doc":"glychee/benchmark","title":"run","content":"pub fn run(functions: List(Function(a, b)), datas: List(Data(a))) -&gt; Nil\n Takes a List of Function and List of Data and runs benchmarks for each\n Function combined with each Data grouped by Data first and Function\n second.\n\n Utilized Benchee and its stdout&#39;s output to print the function&#39;s benchmark\n results for all data.\n\nSynonyms:\nglychee/benchmark.run\nglychee/benchmark run","url":"glychee/benchmark.html#run"},{"doc":"glychee/benchmark","title":"glychee/benchmark","content":" Benchmark\n\n Contain&#39;s custom types and a runner function to process those.\n\n ### Example\n\n ```gleam\n // In your application or library in src/benchmark.gleam:\n import glychee/benchmark\n import gleam/list\n import gleam/int\n\n pub fn main() {\n   benchmark.run(\n     [\n       benchmark.Function(\n         // swap the label for your function name&#39;s\n         label: &quot;list.sort()&quot;,\n         fun: fn(test_data) {\n          fn() {\n            // swap for your function to benchmark\n            list.sort(test_data, int.compare)\n          }\n        },\n       ),\n       // You can add another function here to compare against.\n     ],\n     [\n       // Replace these with data expected by your function(s).\n       benchmark.Data(\n        label: &quot;pre-sorted list&quot;,\n        data: list.range(1, 100_000)\n      ),\n       benchmark.Data(\n         label: &quot;reversed list&quot;,\n         data: list.range(1, 100_000)\n         |&gt; list.reverse,\n       )\n     ],\n   )\n }\n ```\n\n Run via:\n\n ```\n gleam clean &amp;&amp; \\\n gleam build &amp;&amp; \\\n erl -pa ./build/dev/erlang/*/ebin -noshell -eval &#39;gleam@@main:run(benchmark)&#39;\n ```","url":"glychee/benchmark.html"}]);